@@ -19,7 +19,7 @@ from ansurr.functions import check_quiet_print
 from datetime import datetime
 
 sys.tracebacklimit = 0
-version = "0.0.34"
+version = "0.0.35"
 
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
@@ -131,7 +131,8 @@ def main():
 
     if len(glob.glob(output_dir+'/ANSURR_output/out/*.out')) > 0:
         if os.path.exists(output_dir+'/ANSURR_output/scores.out'):
-            plot2D.plot_scores(output_dir+'/ANSURR_output/',cyrange=args.welldef)
+            if not args.min:
+                plot2D.plot_scores(output_dir+'/ANSURR_output/',cyrange=args.welldef)
             check_quiet_print(args.quiet,"summary of ANSURR scores")
             for line in open(output_dir+'/ANSURR_output/scores.out','r'):
                 check_quiet_print(args.quiet," -> "+line.strip())
@@ -140,7 +141,7 @@ def main():
         sys.exit(1)
 
     if args.min:
-        check_quiet_print(args.quiet,' -> scores saved to scores_'+pdb_file+'_'+shift_file+'.out')
+        check_quiet_print(args.quiet,'ANSURR scores saved to scores_'+pdb_file+'_'+shift_file+'.out')
         shutil.move(output_dir+'/ANSURR_output/scores.out','scores_'+pdb_file+'_'+shift_file+'.out')
         shutil.rmtree(output_dir)
 
