@@ -259,17 +259,17 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
     check_quiet_print(quiet," -> "+PDB_ID + '|'+ SHIFT_ID+' ',end='')
 
     # secondary structure
-    """ss_dict = {}
-                try:
-                    secondary_structure_in = open(sys.argv[3],'r')
-                    for line in secondary_structure_in:
-                        line = line.split()
-                        try:
-                            ss_dict[int(line[0])] = line[2]
-                        except:
-                            ss_dict[int(line[0])] = np.nan
-                except:
-                    pass"""
+    ss_dict = {}
+    try:
+        secondary_structure_in = open(output_dir+'/other_output/dssp/'+PDB_ID+'.dssp','r')
+        for line in secondary_structure_in:
+            line = line.split()
+            try:
+                ss_dict[int(line[0])] = line[2]
+            except:
+                pass
+    except:
+        pass
 
     # read in data
     RCI = {'resi':[],'resn':[],'score':[],'shifts':[],'shift_types':[]}
